from setuptools import setup, version

setup(name='Grafico',
    version='0.1.2',
    description='Graphics generation package.',
    packages=['grafico'],
    author='Guilherme Donizetti',
    author_email = 'guilhermetecnologias@gmail.com',
    zip_safe=False)